sqlobject.tests.test\_boundattributes module
============================================

.. automodule:: sqlobject.tests.test_boundattributes
    :members:
    :undoc-members:
    :show-inheritance:
